===================
Administrator Guide
===================

Building Container Images
-------------------------

If you are a system administrator running Kolla, this section contains
information that should help you understand how to build container image
or build some images using ``--template-override``.


.. toctree::
   :maxdepth: 2
   :glob:

   image-building
   template-override/*


Kolla Images API
----------------

Take advantage of the Kolla API to configure containers at runtime.

.. toctree::
   :maxdepth: 2
   :glob:

   kolla_api
